#!/bin/bash

# Check if the system is running in UEFI mode
if [[ -d "/sys/firmware/efi" ]]; then
    # UEFI mode detected
    echo "UEFI system detected. Reinstalling GRUB for UEFI..."
    /usr/bin/systemctl restart systemd-boot-update.service
    bootctl update
else
    # Legacy (BIOS) mode detected
    echo "Legacy (BIOS) system detected. Reinstalling GRUB for BIOS..."

    # Find the primary disk for MBR installations
    primary_disk=$(lsblk -o NAME,SIZE,MOUNTPOINT -nl | awk '$3=="/" {print $1}' | sed 's/[0-9]//g')

    if [[ -n "$primary_disk" ]]; then
        grub-install --target=i386-pc --recheck "/dev/$primary_disk"
        grub-mkconfig -o /boot/grub/grub.cfg
    else
        echo "Error: Unable to determine primary disk. Check your configuration."
        exit 1
    fi
fi

